# reflex-roll

Are you tired of Reflex's default "broken WiFi" indicator when your App's
backend connection is not available?

Would your users would appreciate a more
**fun** and **interesting** indication that your App is completely
non-interactive and it's probably their fault?

Then look no further, `reflex-roll` has you covered.

## Usage

1. `pip install reflex-roll`
2. ???
3. Profit!

## How

`reflex-roll` uses methods previously known only to malware authors in order to
automatically improve your connection error indicator across all apps using the
default `overlay_component`.

As a busy developer 😰, you dont have the energy to worry yourself with updating
your app's actual code, `reflex-roll` will patch your app at compile time on
your behalf, saving you and your users what precious short time and resources we
have left on this planet 🌎.

![Roll on Rollercoaster](https://github.com/masenf/reflex-roll/blob/main/src/reflex_roll/ezgif-7-4353d96d35.gif?raw=true)